package
Version:
v0.0.2
Opens a new window with list of versions in this module.
Published: Jan 26, 2026
License: MIT
Opens a new window with license information.
Imports: 9
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type ReqSaasCreate struct {
UserCode string `json:"userCode"`
OrgCode string `json:"orgCode"`
Name string `json:"name"`
}
type ReqSaasJoin struct {
UserCode string `json:"userCode"`
OrgCode string `json:"orgCode"`
UserName string `json:"userName"`
}
type ReqSaasLeave struct {
UserCode string `json:"userCode"`
OrgCode string `json:"orgCode"`
}
type RespMe struct {
UserId int `json:"userId,omitempty"`
Username string `json:"username,omitempty"`
Nickname string `json:"nickname,omitempty"`
Avatar string `json:"avatar,omitempty"`
Roles []string `json:"roles,omitempty"`
Perms []string `json:"perms,omitempty"`
}
type UserDetailResponse struct {
SecurityInfo *dto.SecurityInfo `json:"securityInfo,omitempty"`
Identities []dto.Identity `json:"identities"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.