package
Version:
v0.0.2
Opens a new window with list of versions in this module.
Published: Jan 26, 2026
License: MIT
Opens a new window with license information.
Imports: 8
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type RespMe struct {
UserId int `json:"userId,omitempty"`
Username string `json:"username,omitempty"`
Nickname string `json:"nickname,omitempty"`
Avatar string `json:"avatar,omitempty"`
Roles []string `json:"roles,omitempty"`
Perms []string `json:"perms,omitempty"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.